# obc2kg

This repo contains the resources (data and scripts) for the workshop entitled "Providing new views on textual data with knowledge graphs" held at the [2nd Heidelberg Summer School of Computing Humanities](https://hch19.cl.uni-heidelberg.de) on July 19th, 2019 by Juri Opitz and Leo Born.

## Repo structure

* _data/_ contains the untagged -- but annotated -- files of the [Old Bailey Corpus](http://fedora.clarin-d.uni-saarland.de/oldbailey/index.html) (OBC)
* _output/_ is used as the default output directory for created knowledge graphs
	* _output/examples/_ contains some sample knowledge graphs for the years 1720, 1820, and 1913
* _src/_ contains all scripts
* _visualization/_ contains the visualization suite (see separate README)

## Requirements

Python >3.0 is recommended. This repo was tested on Ubuntu and macOS (10.14).

### Dependencies

Install with pip:

- beautifulsoup4==4.7.1
- lxml==4.3.4
- matplotlib==3.1.1
- networkx==2.3
- numpy==1.16.4
- pandas==0.24.2
- scikit-learn==0.21.2
- scipy==1.3.0
- seaborn==0.9.0
- spacy==2.1.4

**NOTE**: _spacy_ must not be version 2.1.5!

For spacy to work, you also need an English language model. The smallest one can be downloaded like this:

    python -m spacy download en_core_web_sm
    
For a list of all available models for English, please refer to the official [documentation](https://spacy.io/models/en).
In general, the larger the model is, the better spacy's performance becomes.

## How to create knowledge graphs

The file to interact with to generate knowledge graphs from the OBC is _main.py_.

To re-create the sample knowledge graph for the year 1913, simply type:

    python main.py -year 1913 -output_path ../output/example_graph_1913.json
    
If you want to simplify text description nodes, you can set the flag "-text\_node\_simplification\_mode":

    python main.py -year 1913 -output_path ../output/example_graph_1913_simplified.json -text_node_simplification_mode classifier

For the classifier, the more years are used as training data, the better its simplification accuracy becomes.\
You can add more years by simply adding years to the command:
    
    python main.py -year 1820 1821 1822 -output_path ../output/example_graph_1820-1822.json

To display all available options, type:

    python main.py -h

## Investigation of punishments over time and gender

    python plot_gender.py -h

For example, we can statistically show that the prison-punishment was "invented" in 19th century.

    python plot_gender.py imprison

Output:

![plot](src/imprison-gender-time.png)

On the y axis we see the ratio of females/males which were sentenced to prison... by mid-19th century almost half of males and females were sentenced to prison in Old Bailey's court


## More

The code can be improved in some places and some things may not be modeled ideally (yet). If you find any bugs or have questions, shoot us an email: lastname@cl.uni-heidelberg.de
